@@ -58,46 +58,3 @@ test_that("derive_var_afeye Test 2: AFEYE is derived correctly when parsing loc_
     keys = c("STUDYID", "USUBJID", "AELOC", "AELAT")
   )
 })
-
-## Test 3: Deprecation of dataset_occ ----
-test_that("derive_var_afeye Test 3: Deprecation of dataset_occ", {
-  expected_output3 <- tibble::tribble(
-    ~STUDYID, ~USUBJID, ~STUDYEYE, ~AELOC, ~AELAT, ~AFEYE,
-    "XXX001", "P01", "RIGHT", "EYE", "RIGHT", "Study Eye",
-    "XXX001", "P01", "RIGHT", "EYE", "LEFT", "Fellow Eye",
-    "XXX001", "P01", "RIGHT", "", "", NA_character_,
-  )
-
-  expect_error(
-    actual_output3 <- expected_output3 %>%
-      select(-AFEYE) %>%
-      derive_var_afeye(
-        dataset = NULL,
-        dataset_occ = .,
-        loc_var = AELOC,
-        lat_var = AELAT
-      ),
-    class = "lifecycle_error_deprecated"
-  )
-})
-
-## Test 4: Deprecation of lat_vals ----
-test_that("derive_var_afeye Test 4: Deprecation of lat_vals", {
-  expected_output4 <- tibble::tribble(
-    ~STUDYID, ~USUBJID, ~STUDYEYE, ~AELOC, ~AELAT, ~AFEYE,
-    "XXX001", "P01", "RIGHT", "EYE", "RIGHT", "Study Eye",
-    "XXX001", "P01", "RIGHT", "EYE", "LEFT", "Fellow Eye",
-    "XXX001", "P01", "RIGHT", "", "", NA_character_,
-  )
-
-  expect_error(
-    actual_output4 <- expected_output4 %>%
-      select(-AFEYE) %>%
-      derive_var_afeye(
-        loc_var = AELOC,
-        lat_var = AELAT,
-        lat_vals = c("LEFT", "RIGHT", "BILATERAL")
-      ),
-    class = "lifecycle_error_deprecated"
-  )
-})
